/* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
 * $Id: sg_all_groves.hpp 1739 2016-04-04 07:42:44Z stephane $
 */

#pragma once

// Central include file for SeeedGrove++ is "sg++.hpp".

#include "sg_groves.hpp"
#include "sg_GroveBase.hpp"
#include "sg_GroveI2C.hpp"
#include "sg_GroveI2CAnalog.hpp"
#include "sg_GroveI2CDigital.hpp"
#include "sg_GroveUART.hpp"
#include "sg_GroveGPIO.hpp"

// http://www.seeedstudio.com/wiki/Grove_System#Grove_Modules

#include "sg_EnvironmentalMonitoring.hpp"
#include "sg_MotionSensing.hpp"
#include "sg_UserInterface.hpp"
#include "sg_PhysicalMonitoring.hpp"
